import { Container } from "@/components/ui/container";
import { motion } from "framer-motion";
import { useReveal } from "@/hooks/use-reveal";
import { Button } from "@/components/ui/button";
import { Settings, Upload, BarChart2 } from "lucide-react";

const steps = [
  {
    number: "1",
    icon: <Settings className="h-6 w-6 text-white" />,
    iconBg: "bg-[#7B61FF]",
    title: "Configure Once",
    description: "Set up your organization's travel needs just once. Create templates for recurring destinations that you regularly visit.",
    badge: "Chicago Tournament",
    badgeTag: "Template",
  },
  {
    number: "2",
    icon: <Upload className="h-6 w-6 text-white" />,
    iconBg: "bg-[#7B61FF]",
    title: "Click Once",
    description: "Instantly book entire travel packages with a single click or share secure booking links with your team members.",
    buttonText: "Book Again →",
  },
  {
    number: "3",
    icon: <BarChart2 className="h-6 w-6 text-white" />,
    iconBg: "bg-[#7B61FF]",
    title: "Gain Insights",
    description: "Track spending patterns, optimize future travel costs, and get a complete picture of your organization's travel activity.",
    badge: "Real-time spending analytics",
  },
];

export default function HowItWorksSection() {
  const { ref: titleRef, inView: titleInView } = useReveal();

  return (
    <section id="how-it-works" className="pt-16 md:pt-20 pb-20 md:pb-28 relative">
      {/* Very subtle pattern background */}
      <div className="absolute inset-0 bg-[url('data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iNjAiIGhlaWdodD0iNjAiIHZpZXdCb3g9IjAgMCA2MCA2MCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj48ZyBmaWxsPSJub25lIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiPjxnIGZpbGw9IiM3QjYxRkYiIGZpbGwtb3BhY2l0eT0iMC4wMSI+PGNpcmNsZSBjeD0iMiIgY3k9IjIiIHI9IjIiLz48L2c+PC9nPjwvc3ZnPg==')] bg-[length:30px_30px] opacity-10 -z-10"></div>
      {/* Very subtle top connector */}
      <div className="absolute top-0 left-0 w-full h-px bg-gray-50"></div>
      
      <Container className="px-6 md:px-8">
        <motion.div 
          className="max-w-3xl mx-auto mb-12"
          ref={titleRef}
          initial={{ opacity: 0, y: 30 }}
          animate={titleInView ? { opacity: 1, y: 0 } : {}}
          transition={{ duration: 0.8 }}
        >
          <div className="flex flex-col items-center">
            <div className="w-12 h-12 bg-[#7B61FF] rounded-full flex items-center justify-center mb-4">
              <Settings className="h-6 w-6 text-white" />
            </div>
            <div className="text-[#7B61FF] font-medium uppercase tracking-wider text-sm mb-2">HOW IT WORKS</div>
            <h2 className="text-3xl md:text-4xl font-medium text-gray-900 text-center">
              Configure once → Click once
            </h2>
          </div>
          <p className="mt-4 text-base text-gray-600 leading-relaxed text-center max-w-2xl mx-auto">
            Recurro turns hours of travel coordination into minutes
          </p>
        </motion.div>
        
        <div className="grid md:grid-cols-3 gap-8 relative">          
          {steps.map((step, index) => {
            const { ref, inView } = useReveal({ threshold: 0.1, delay: 0.1 * index });
            
            return (
              <motion.div
                key={step.title}
                ref={ref}
                initial={{ opacity: 0, y: 30 }}
                animate={inView ? { opacity: 1, y: 0 } : {}}
                transition={{ duration: 0.6, delay: 0.15 * index }}
                className="bg-white border border-gray-100 rounded-lg p-8 shadow-sm hover:shadow-md transition-all duration-300"
              >
                <div className="flex items-center mb-5">
                  <div className={`w-10 h-10 ${step.iconBg} rounded-full flex items-center justify-center`}>
                    {step.icon}
                  </div>
                  <div className="ml-3 text-xl font-medium text-gray-900">{step.number}. {step.title}</div>
                </div>
                
                <p className="text-gray-600 leading-relaxed mb-5">{step.description}</p>
                
                {step.badge && (
                  <div className="flex items-center bg-[#F7F0FF] p-3 rounded mb-3">
                    <div className="w-6 h-6 bg-[#7B61FF] rounded-full text-white flex items-center justify-center text-xs font-bold mr-2">
                      {step.number === "1" ? "TC" : ""}
                      {step.number === "3" ? "$" : ""}
                    </div>
                    <span className="text-sm font-medium">{step.badge}</span>
                    {step.badgeTag && (
                      <span className="ml-auto bg-[#F0E6FF] text-[#7B61FF] text-xs py-1 px-2 rounded">
                        {step.badgeTag}
                      </span>
                    )}
                  </div>
                )}
                
                {step.buttonText && (
                  <div className="mt-6">
                    <Button className="bg-[#7B61FF] hover:bg-[#6A50DE] text-white py-2 px-5 rounded text-sm">
                      {step.buttonText}
                    </Button>
                  </div>
                )}
              </motion.div>
            );
          })}
        </div>
      </Container>
    </section>
  );
}
